@@ -15,11 +15,8 @@ from typing import (
 
 import aiohttp
 import rasa.core
-from rasa.core.constants import (
-    DEFAULT_REQUEST_TIMEOUT,
-    COMPRESS_ACTION_SERVER_REQUEST_ENV_NAME,
-    DEFAULT_COMPRESS_ACTION_SERVER_REQUEST,
-)
+from rasa.core.actions.constants import DEFAULT_SELECTIVE_DOMAIN, SELECTIVE_DOMAIN
+from rasa.core.constants import DEFAULT_REQUEST_TIMEOUT
 from rasa.core.policies.policy import PolicyPrediction
 from rasa.nlu.constants import (
     RESPONSE_SELECTOR_DEFAULT_INTENT,
@@ -79,7 +76,6 @@ from rasa.shared.nlu.constants import (
 )
 from rasa.shared.utils.schemas.events import EVENTS_SCHEMA
 import rasa.shared.utils.io
-from rasa.utils.common import get_bool_env_variable
 from rasa.utils.endpoints import EndpointConfig, ClientResponseError
 
 if TYPE_CHECKING:
@@ -641,27 +637,44 @@ class RemoteAction(Action):
         self.action_endpoint = action_endpoint
 
     def _action_call_format(
-        self, tracker: "DialogueStateTracker", domain: "Domain"
+        self,
+        tracker: "DialogueStateTracker",
+        domain: "Domain",
     ) -> Dict[Text, Any]:
         """Create the request json send to the action server."""
         from rasa.shared.core.trackers import EventVerbosity
 
         tracker_state = tracker.current_state(EventVerbosity.ALL)
 
-        return {
+        result = {
             "next_action": self._name,
             "sender_id": tracker.sender_id,
             "tracker": tracker_state,
-            "domain": domain.as_dict(),
             "version": rasa.__version__,
         }
 
+        if (
+            not self._is_selective_domain_enabled()
+            or domain.does_custom_action_explicitly_need_domain(self.name())
+        ):
+            result["domain"] = domain.as_dict()
+
+        return result
+
+    def _is_selective_domain_enabled(self) -> bool:
+        if self.action_endpoint is None:
+            return False
+        return bool(
+            self.action_endpoint.kwargs.get(SELECTIVE_DOMAIN, DEFAULT_SELECTIVE_DOMAIN)
+        )
+
     @staticmethod
     def action_response_format_spec() -> Dict[Text, Any]:
         """Expected response schema for an Action endpoint.
 
         Used for validation of the response returned from the
-        Action endpoint."""
+        Action endpoint.
+        """
         schema = {
             "type": "object",
             "properties": {
@@ -743,17 +756,8 @@ class RemoteAction(Action):
             logger.debug(
                 "Calling action endpoint to run action '{}'.".format(self.name())
             )
-
-            should_compress = get_bool_env_variable(
-                COMPRESS_ACTION_SERVER_REQUEST_ENV_NAME,
-                DEFAULT_COMPRESS_ACTION_SERVER_REQUEST,
-            )
-
             response: Any = await self.action_endpoint.request(
-                json=json_body,
-                method="post",
-                timeout=DEFAULT_REQUEST_TIMEOUT,
-                compress=should_compress,
+                json=json_body, method="post", timeout=DEFAULT_REQUEST_TIMEOUT
             )
 
             self._validate_action_result(response)
@@ -1008,7 +1012,7 @@ class ActionExtractSlots(Action):
     Action is executed automatically in MessageProcessor.handle_message(...)
     before the next predicted action is run.
 
-    Set slots to extracted values from user message
+    Sets slots to extracted values from user message
     according to assigned slot mappings.
     """
 
